@@ -1,13 +1,13 @@
 import sys
 import tempfile
-from os import getcwd, walk, remove, environ
-from os.path import realpath, exists, isdir, join
+from os import environ, getcwd, remove, walk
+from os.path import exists, isdir, join, realpath
 from pathlib import Path
 from shutil import rmtree
 
-from pyorbs.templates import render
-from pyorbs.shell import execute, current_shell_type, SHELLS, which
 from pyorbs.reqs import Requirements
+from pyorbs.shell import SHELLS, current_shell_type, execute, which
+from pyorbs.templates import render
 
 
 class Orbs:
@@ -18,7 +18,7 @@ class Orbs:
 
     def list(self):
         orbs = [orb + ' *' if orb == self.glowing() else orb for orb in self.orbs]
-        print('\n'.join(orbs) if orbs else 'There are no orbs')
+        print('\n'.join(sorted(orbs)) if orbs else 'There are no orbs')
 
     @staticmethod
     def freeze(reqs, executable=sys.executable):
@@ -185,6 +185,11 @@ class Orb:
             self._orbs.toggle_glow(self.name)
         rmtree(join(self._orbs.path, self.name))
 
+    def info(self):
+        print('Orb "%s"' % self.name)
+        old = self.activate(run='pip list --outdated', capture=True)
+        print('\n' + (old.stdout.rstrip() if old.stdout else 'All packages are up-to-date'))
+
     def activate(self, run=None, no_cd=False, capture=False):
         """
         Activate the orb.
